==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/finders/IndexSetComparator.h <==
// class soot.dava.toolkits.base.finders.IndexSetComparator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9cb9af1a72955b37 soot_dava_toolkits_base_finders_IndexSetComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_IndexSetComparator_H_
#define _JC_soot_dava_toolkits_base_finders_IndexSetComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_refs	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$refs	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$nonrefs	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vmethods	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtable	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtype	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_IndexSetComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object *);

// Virtual methods
extern jint _jc_soot_dava_toolkits_base_finders_IndexSetComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_soot_dava_toolkits_base_finders_IndexSetComparator$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_IndexSetComparator$method_info$compare$ef65339aa5f9531b;
extern _jc_method _jc_soot_dava_toolkits_base_finders_IndexSetComparator$method_info$equals$8a15e0625571c581;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vmethods	soot_dava_toolkits_base_finders_IndexSetComparator;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$refs {
    _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_refs	soot_dava_toolkits_base_finders_IndexSetComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_nonrefs	soot_dava_toolkits_base_finders_IndexSetComparator;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object {
	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtype _jc_soot_dava_toolkits_base_finders_IndexSetComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_IndexSetComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_IndexSetComparator$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_IndexSetComparator_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/finders/IndexSetComparator.h <==
// class soot.dava.toolkits.base.finders.IndexSetComparator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9cb9af1a72955b37 soot_dava_toolkits_base_finders_IndexSetComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_IndexSetComparator_H_
#define _JC_soot_dava_toolkits_base_finders_IndexSetComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_refs	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$refs	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$nonrefs	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vmethods	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtable	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtype	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_IndexSetComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_dava_toolkits_base_finders_IndexSetComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_toolkits_base_finders_IndexSetComparator$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_IndexSetComparator$method_info$compare$ef65339aa5f9531b;
extern _jc_method _jc_soot_dava_toolkits_base_finders_IndexSetComparator$method_info$equals$8a15e0625571c581;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vmethods	soot_dava_toolkits_base_finders_IndexSetComparator;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$refs {
    _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_refs	soot_dava_toolkits_base_finders_IndexSetComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_IndexSetComparator$sub_nonrefs	soot_dava_toolkits_base_finders_IndexSetComparator;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_IndexSetComparator$object {
	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_IndexSetComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_IndexSetComparator$vtype _jc_soot_dava_toolkits_base_finders_IndexSetComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_IndexSetComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_IndexSetComparator$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_IndexSetComparator_H_ */
